summaryrefslogtreecommitdiffstats
path: root/client
diff options
context:
space:
mode:
authorLeif Åstrand <leif@vaadin.com>2012-12-13 11:03:50 +0200
committerLeif Åstrand <leif@vaadin.com>2012-12-13 11:03:50 +0200
commitac1b5cb7a1216ef7299e970bd014487e43755fd6 (patch)
tree3cbffbe877225b8b0855c209b9cfaf3e711d2228 /client
parent21cfeb145c81fabfc935a136cff581d53754a27d (diff)
downloadvaadin-framework-ac1b5cb7a1216ef7299e970bd014487e43755fd6.tar.gz
vaadin-framework-ac1b5cb7a1216ef7299e970bd014487e43755fd6.zip
Fix selector backwards compatibility (#9893)
Change-Id: Ib69645f9cc866893b8a85e369414b7c15b440b6e
Diffstat (limited to 'client')
-rw-r--r--client/src/com/vaadin/client/ComponentLocator.java20
1 files changed, 4 insertions, 16 deletions
diff --git a/client/src/com/vaadin/client/ComponentLocator.java b/client/src/com/vaadin/client/ComponentLocator.java
index 249c3f78f4..16e8859d01 100644
--- a/client/src/com/vaadin/client/ComponentLocator.java
+++ b/client/src/com/vaadin/client/ComponentLocator.java
@@ -24,7 +24,6 @@ import com.google.gwt.user.client.DOM;
import com.google.gwt.user.client.Element;
import com.google.gwt.user.client.ui.HasWidgets;
import com.google.gwt.user.client.ui.RootPanel;
-import com.google.gwt.user.client.ui.SimplePanel;
import com.google.gwt.user.client.ui.Widget;
import com.vaadin.client.ui.SubPartAware;
import com.vaadin.client.ui.VCssLayout;
@@ -562,10 +561,11 @@ public class ComponentLocator {
continue;
}
// ChildComponentContainer has been removed and replaced with
// Slot
if (w instanceof VAbstractOrderedLayout
- && "ChildComponentContainer".equals(widgetClassName)) {
+ && ("ChildComponentContainer".equals(widgetClassName) || "VOrderedLayout$Slot"
+ .equals(widgetClassName))) {
widgetClassName = "Slot";
}
@@ -662,18 +662,6 @@ public class ComponentLocator {
}
widgetPosition--;
- } else if (w instanceof VAbstractOrderedLayout
- && "Slot".equals(simpleName2)) {
- child = ((SimplePanel) child).getWidget();
- simpleName2 = Util.getSimpleName(child);
- if (widgetClassName.equals(simpleName2)) {
- if (widgetPosition == 0) {
- w = child;
- ok = true;
- break;
- }
- widgetPosition--;
- }
}
}
@@ -562,10 +561,11 @@ public class ComponentLocator {
continue;
}
- // ChildComponentContainer has been removed and replaced with
- // Slot
+ // ChildComponentContainer and VOrderedLayout$Slot have been
+ // replaced with Slot
if (w instanceof VAbstractOrderedLayout